# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_condition import ServingCondition
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_resources import ServingResources
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeApplicationResponse(BaseModel):
    """
    ServingDescribeApplicationResponse
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    conditions: Optional[List[ServingCondition]] = None
    subdomain: Optional[StrictStr] = None
    observed_generation: Optional[StrictInt] = None
    created_by: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    resources: Optional[ServingResources] = None
    revisions: Optional[List[ServingApplicationRevision]] = None
    relevant_revisions: Optional[ServingRelevantRevisionsMeta] = None
    autoscaling: Optional[ServingAutoscaling] = None
    state: Optional[StrictStr] = None
    last_updated_at: Optional[datetime] = None
    is_web_app: Optional[StrictBool] = None
    source_url: Optional[StrictStr] = Field(default=None, description="The URL of the application source (container or directory)")
    __properties: ClassVar[List[str]] = ["namespace", "name", "url", "conditions", "subdomain", "observed_generation", "created_by", "description", "created_at", "resources", "revisions", "relevant_revisions", "autoscaling", "state", "last_updated_at", "is_web_app", "source_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeApplicationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item_conditions in self.conditions:
                if _item_conditions:
                    _items.append(_item_conditions.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in revisions (list)
        _items = []
        if self.revisions:
            for _item_revisions in self.revisions:
                if _item_revisions:
                    _items.append(_item_revisions.to_dict())
            _dict['revisions'] = _items
        # override the default output from pydantic by calling `to_dict()` of relevant_revisions
        if self.relevant_revisions:
            _dict['relevant_revisions'] = self.relevant_revisions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeApplicationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "conditions": [ServingCondition.from_dict(_item) for _item in obj["conditions"]] if obj.get("conditions") is not None else None,
            "subdomain": obj.get("subdomain"),
            "observed_generation": obj.get("observed_generation"),
            "created_by": obj.get("created_by"),
            "description": obj.get("description"),
            "created_at": obj.get("created_at"),
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "revisions": [ServingApplicationRevision.from_dict(_item) for _item in obj["revisions"]] if obj.get("revisions") is not None else None,
            "relevant_revisions": ServingRelevantRevisionsMeta.from_dict(obj["relevant_revisions"]) if obj.get("relevant_revisions") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "state": obj.get("state"),
            "last_updated_at": obj.get("last_updated_at"),
            "is_web_app": obj.get("is_web_app"),
            "source_url": obj.get("source_url")
        })
        return _obj


