# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_condition import ServingCondition
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision
from cloudera.ai.inference.models.serving_model_status import ServingModelStatus
from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_resources import ServingResources
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo
from cloudera.ai.inference.models.serving_traffic import ServingTraffic
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeEndpointResponse(BaseModel):
    """
    ServingDescribeEndpointResponse
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    conditions: Optional[List[ServingCondition]] = None
    status: Optional[ServingModelStatus] = None
    observed_generation: Optional[StrictInt] = None
    replica_count: Optional[StrictInt] = None
    created_by: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    resources: Optional[ServingResources] = None
    revisions: Optional[List[ServingModelRevision]] = None
    autoscaling: Optional[ServingAutoscaling] = None
    relevant_revisions: Optional[ServingRelevantRevisionsMeta] = None
    model_name: Optional[StrictStr] = None
    traffic: Optional[ServingTraffic] = None
    api_standard: Optional[StrictStr] = None
    has_chat_template: Optional[StrictBool] = None
    metric_format: Optional[StrictStr] = None
    task: Optional[StrictStr] = None
    instance_type: Optional[StrictStr] = None
    optimization_profile: Optional[ServingOptimizationProfile] = None
    crn: Optional[StrictStr] = None
    inference_logging_config: Optional[ServingInferenceLoggingConfig] = None
    runtime_info: Optional[ServingRuntimeInfo] = None
    vllm_args: Optional[StrictStr] = None
    deployment_mode: Optional[StrictStr] = None
    environment_variables: Optional[List[ServingEnvironmentVariable]] = None
    gpu_type: Optional[StrictStr] = Field(default=None, alias="gpuType")
    tags: Optional[List[ServingLabel]] = None
    rate_limit: Optional[ServingRateLimitConfig] = Field(default=None, description="current rate limit configuration for this endpoint")
    state: Optional[StrictStr] = Field(default=None, description="unified state field that matches listEndpoints response for consistency")
    __properties: ClassVar[List[str]] = ["namespace", "name", "url", "conditions", "status", "observed_generation", "replica_count", "created_by", "description", "created_at", "resources", "revisions", "autoscaling", "relevant_revisions", "model_name", "traffic", "api_standard", "has_chat_template", "metric_format", "task", "instance_type", "optimization_profile", "crn", "inference_logging_config", "runtime_info", "vllm_args", "deployment_mode", "environment_variables", "gpuType", "tags", "rate_limit", "state"]

    @field_validator('deployment_mode')
    def deployment_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DEPLOYMENT_MODE_UNKNOWN', 'KNATIVE', 'RAW_DEPLOYMENT']):
            raise ValueError("must be one of enum values ('DEPLOYMENT_MODE_UNKNOWN', 'KNATIVE', 'RAW_DEPLOYMENT')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeEndpointResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item_conditions in self.conditions:
                if _item_conditions:
                    _items.append(_item_conditions.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in revisions (list)
        _items = []
        if self.revisions:
            for _item_revisions in self.revisions:
                if _item_revisions:
                    _items.append(_item_revisions.to_dict())
            _dict['revisions'] = _items
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of relevant_revisions
        if self.relevant_revisions:
            _dict['relevant_revisions'] = self.relevant_revisions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of traffic
        if self.traffic:
            _dict['traffic'] = self.traffic.to_dict()
        # override the default output from pydantic by calling `to_dict()` of optimization_profile
        if self.optimization_profile:
            _dict['optimization_profile'] = self.optimization_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of inference_logging_config
        if self.inference_logging_config:
            _dict['inference_logging_config'] = self.inference_logging_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of runtime_info
        if self.runtime_info:
            _dict['runtime_info'] = self.runtime_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in environment_variables (list)
        _items = []
        if self.environment_variables:
            for _item_environment_variables in self.environment_variables:
                if _item_environment_variables:
                    _items.append(_item_environment_variables.to_dict())
            _dict['environment_variables'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # override the default output from pydantic by calling `to_dict()` of rate_limit
        if self.rate_limit:
            _dict['rate_limit'] = self.rate_limit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeEndpointResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "conditions": [ServingCondition.from_dict(_item) for _item in obj["conditions"]] if obj.get("conditions") is not None else None,
            "status": ServingModelStatus.from_dict(obj["status"]) if obj.get("status") is not None else None,
            "observed_generation": obj.get("observed_generation"),
            "replica_count": obj.get("replica_count"),
            "created_by": obj.get("created_by"),
            "description": obj.get("description"),
            "created_at": obj.get("created_at"),
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "revisions": [ServingModelRevision.from_dict(_item) for _item in obj["revisions"]] if obj.get("revisions") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "relevant_revisions": ServingRelevantRevisionsMeta.from_dict(obj["relevant_revisions"]) if obj.get("relevant_revisions") is not None else None,
            "model_name": obj.get("model_name"),
            "traffic": ServingTraffic.from_dict(obj["traffic"]) if obj.get("traffic") is not None else None,
            "api_standard": obj.get("api_standard"),
            "has_chat_template": obj.get("has_chat_template"),
            "metric_format": obj.get("metric_format"),
            "task": obj.get("task"),
            "instance_type": obj.get("instance_type"),
            "optimization_profile": ServingOptimizationProfile.from_dict(obj["optimization_profile"]) if obj.get("optimization_profile") is not None else None,
            "crn": obj.get("crn"),
            "inference_logging_config": ServingInferenceLoggingConfig.from_dict(obj["inference_logging_config"]) if obj.get("inference_logging_config") is not None else None,
            "runtime_info": ServingRuntimeInfo.from_dict(obj["runtime_info"]) if obj.get("runtime_info") is not None else None,
            "vllm_args": obj.get("vllm_args"),
            "deployment_mode": obj.get("deployment_mode"),
            "environment_variables": [ServingEnvironmentVariable.from_dict(_item) for _item in obj["environment_variables"]] if obj.get("environment_variables") is not None else None,
            "gpuType": obj.get("gpuType"),
            "tags": [ServingLabel.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "rate_limit": ServingRateLimitConfig.from_dict(obj["rate_limit"]) if obj.get("rate_limit") is not None else None,
            "state": obj.get("state")
        })
        return _obj


