# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_third_party_source import ServingThirdPartySource

class TestServingThirdPartySource(unittest.TestCase):
    """ServingThirdPartySource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingThirdPartySource:
        """Test ServingThirdPartySource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingThirdPartySource`
        """
        model = ServingThirdPartySource()
        if include_optional:
            return ServingThirdPartySource(
                url = '',
                model = '',
                provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED',
                api_key = '',
                aws_credentials = cloudera.ai.inference.models.serving/aws_credentials.serving.AWSCredentials(
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', 
                    bearer_token = '', ),
                gcp_credentials = cloudera.ai.inference.models.serving/gcp_credentials.serving.GCPCredentials(
                    service_account_json = '', 
                    project_name = '', 
                    region = '', ),
                api_version = '',
                path_prefix = ''
            )
        else:
            return ServingThirdPartySource(
        )
        """

    def testServingThirdPartySource(self):
        """Test ServingThirdPartySource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
