# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_service_health_response import ServingDescribeServiceHealthResponse

class TestServingDescribeServiceHealthResponse(unittest.TestCase):
    """ServingDescribeServiceHealthResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeServiceHealthResponse:
        """Test ServingDescribeServiceHealthResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeServiceHealthResponse`
        """
        model = ServingDescribeServiceHealthResponse()
        if include_optional:
            return ServingDescribeServiceHealthResponse(
                cml_serving_api = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                kubernetes = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                knative = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                kserve = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                istio = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                cml_registry = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                cml_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                archiver_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                usage_reporter_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                authorizer_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', )
            )
        else:
            return ServingDescribeServiceHealthResponse(
        )
        """

    def testServingDescribeServiceHealthResponse(self):
        """Test ServingDescribeServiceHealthResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
