# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_deploy_application_request import ServingDeployApplicationRequest

class TestServingDeployApplicationRequest(unittest.TestCase):
    """ServingDeployApplicationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDeployApplicationRequest:
        """Test ServingDeployApplicationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDeployApplicationRequest`
        """
        model = ServingDeployApplicationRequest()
        if include_optional:
            return ServingDeployApplicationRequest(
                namespace = '',
                name = '',
                subdomain = '',
                source = cloudera.ai.inference.models.serving/application_source.serving.ApplicationSource(
                    container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                        url = '', 
                        environment_variables = [
                            cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                                name = '', 
                                value = '', )
                            ], 
                        username = '', 
                        access_token = '', ), 
                    directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                        url = '', 
                        entry_point = '', 
                        runtime_image = '', 
                        credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                            github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                                username = '', 
                                ssh_key = '', 
                                access_token = '', ), 
                            s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                                access_key_id = '', 
                                secret_access_key = '', ), ), ), ),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                labels = [
                    cloudera.ai.inference.models.serving/label.serving.Label(
                        key = '', 
                        value = '', )
                    ],
                description = '',
                traffic = '',
                instance_type = '',
                is_update = True,
                is_web_app = True
            )
        else:
            return ServingDeployApplicationRequest(
        )
        """

    def testServingDeployApplicationRequest(self):
        """Test ServingDeployApplicationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
