# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.api.serving_api import ServingApi


class TestServingApi(unittest.TestCase):
    """ServingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServingApi()

    def tearDown(self) -> None:
        pass

    def test_serving_create_cluster_log_archive(self) -> None:
        """Test case for serving_create_cluster_log_archive

        """
        pass

    def test_serving_delete_application(self) -> None:
        """Test case for serving_delete_application

        """
        pass

    def test_serving_delete_cluster_log_archive(self) -> None:
        """Test case for serving_delete_cluster_log_archive

        """
        pass

    def test_serving_delete_endpoint(self) -> None:
        """Test case for serving_delete_endpoint

        """
        pass

    def test_serving_delete_endpoint_rate_limit(self) -> None:
        """Test case for serving_delete_endpoint_rate_limit

        """
        pass

    def test_serving_deploy_application(self) -> None:
        """Test case for serving_deploy_application

        """
        pass

    def test_serving_deploy_endpoint(self) -> None:
        """Test case for serving_deploy_endpoint

        """
        pass

    def test_serving_describe_application(self) -> None:
        """Test case for serving_describe_application

        """
        pass

    def test_serving_describe_endpoint(self) -> None:
        """Test case for serving_describe_endpoint

        """
        pass

    def test_serving_describe_service(self) -> None:
        """Test case for serving_describe_service

        """
        pass

    def test_serving_describe_service_health(self) -> None:
        """Test case for serving_describe_service_health

        """
        pass

    def test_serving_get_allowed_environment_variables(self) -> None:
        """Test case for serving_get_allowed_environment_variables

        """
        pass

    def test_serving_get_allowed_vllm_args(self) -> None:
        """Test case for serving_get_allowed_vllm_args

        """
        pass

    def test_serving_get_api_logs(self) -> None:
        """Test case for serving_get_api_logs

        """
        pass

    def test_serving_get_application_logs(self) -> None:
        """Test case for serving_get_application_logs

        """
        pass

    def test_serving_get_endpoint_events(self) -> None:
        """Test case for serving_get_endpoint_events

        """
        pass

    def test_serving_get_endpoint_logs(self) -> None:
        """Test case for serving_get_endpoint_logs

        """
        pass

    def test_serving_get_endpoint_rate_limit(self) -> None:
        """Test case for serving_get_endpoint_rate_limit

        """
        pass

    def test_serving_get_quota_usage(self) -> None:
        """Test case for serving_get_quota_usage

        """
        pass

    def test_serving_grant_permission(self) -> None:
        """Test case for serving_grant_permission

        """
        pass

    def test_serving_list_applications(self) -> None:
        """Test case for serving_list_applications

        """
        pass

    def test_serving_list_cluster_log_archives(self) -> None:
        """Test case for serving_list_cluster_log_archives

        """
        pass

    def test_serving_list_cluster_resources(self) -> None:
        """Test case for serving_list_cluster_resources

        """
        pass

    def test_serving_list_endpoints(self) -> None:
        """Test case for serving_list_endpoints

        """
        pass

    def test_serving_list_permissions(self) -> None:
        """Test case for serving_list_permissions

        """
        pass

    def test_serving_ping(self) -> None:
        """Test case for serving_ping

        """
        pass

    def test_serving_revoke_permission(self) -> None:
        """Test case for serving_revoke_permission

        """
        pass

    def test_serving_set_endpoint_rate_limit(self) -> None:
        """Test case for serving_set_endpoint_rate_limit

        """
        pass

    def test_serving_start_endpoint(self) -> None:
        """Test case for serving_start_endpoint

        """
        pass

    def test_serving_stop_endpoint(self) -> None:
        """Test case for serving_stop_endpoint

        """
        pass

    def test_serving_toggle_features(self) -> None:
        """Test case for serving_toggle_features

        """
        pass

    def test_serving_update_endpoint(self) -> None:
        """Test case for serving_update_endpoint

        """
        pass

    def test_serving_update_inference_logging_config(self) -> None:
        """Test case for serving_update_inference_logging_config

        """
        pass


if __name__ == '__main__':
    unittest.main()
