# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig

class TestServingInferenceLoggingConfig(unittest.TestCase):
    """ServingInferenceLoggingConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingInferenceLoggingConfig:
        """Test ServingInferenceLoggingConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingInferenceLoggingConfig`
        """
        model = ServingInferenceLoggingConfig()
        if include_optional:
            return ServingInferenceLoggingConfig(
                enabled = True,
                explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                    bucket_url = '', 
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', ),
                explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                    bucket_url = '', 
                    client_id = '', 
                    client_secret = '', 
                    tenant_id = '', 
                    subscription_id = '', 
                    access_token = '', 
                    access_token_expiration_seconds = 56, 
                    service_url = '', ),
                explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                    bucket_url = '', 
                    key_file = '', ),
                explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                    datalake_crn = '', 
                    path = '', 
                    resolved_storage_url = '', ),
                predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                    bucket_url = '', 
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', ),
                predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                    bucket_url = '', 
                    client_id = '', 
                    client_secret = '', 
                    tenant_id = '', 
                    subscription_id = '', 
                    access_token = '', 
                    access_token_expiration_seconds = 56, 
                    service_url = '', ),
                predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                    bucket_url = '', 
                    key_file = '', ),
                predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                    datalake_crn = '', 
                    path = '', 
                    resolved_storage_url = '', ),
                transformer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                    bucket_url = '', 
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', ),
                transformer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                    bucket_url = '', 
                    client_id = '', 
                    client_secret = '', 
                    tenant_id = '', 
                    subscription_id = '', 
                    access_token = '', 
                    access_token_expiration_seconds = 56, 
                    service_url = '', ),
                transformer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                    bucket_url = '', 
                    key_file = '', ),
                transformer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                    datalake_crn = '', 
                    path = '', 
                    resolved_storage_url = '', ),
                format = 'LOGGING_FORMAT_UNKNOWN',
                batch_size = 56,
                rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN'
            )
        else:
            return ServingInferenceLoggingConfig(
        )
        """

    def testServingInferenceLoggingConfig(self):
        """Test ServingInferenceLoggingConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
