# coding: utf-8

# flake8: noqa

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1+devel"

# Define package exports
__all__ = [
    "ServingApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ArchiverClusterLogArchiveMetadata",
    "ArchiverCreateClusterLogArchiveRequest",
    "ArchiverCreateClusterLogArchiveResponse",
    "ArchiverDeleteClusterLogArchiveRequest",
    "ArchiverDeleteClusterLogArchiveResponse",
    "ArchiverListClusterLogArchivesRequest",
    "ArchiverListClusterLogArchivesResponse",
    "AuthorizerGrantPermissionRequest",
    "AuthorizerListPermissionsRequest",
    "AuthorizerListPermissionsResponse",
    "AuthorizerPermission",
    "AuthorizerPermissions",
    "AuthorizerResource",
    "AuthorizerRevokePermissionRequest",
    "AuthorizerSubject",
    "GoogleProtobufAny",
    "GoogleRpcStatus",
    "ServingABSInferenceLoggingConfig",
    "ServingAWSCredentials",
    "ServingApplicationContainerSource",
    "ServingApplicationDescriptor",
    "ServingApplicationDirectorySource",
    "ServingApplicationDirectorySourceCredentials",
    "ServingApplicationRevision",
    "ServingApplicationSource",
    "ServingAutoscaling",
    "ServingAutoscalingConfig",
    "ServingCondition",
    "ServingDataLakeLoggingConfig",
    "ServingDeleteApplicationRequest",
    "ServingDeleteEndpointRateLimitRequest",
    "ServingDeleteEndpointRequest",
    "ServingDeployApplicationRequest",
    "ServingDeployEndpointRequest",
    "ServingDeployEndpointResponse",
    "ServingDescribeApplicationRequest",
    "ServingDescribeApplicationResponse",
    "ServingDescribeEndpointRequest",
    "ServingDescribeEndpointResponse",
    "ServingDescribeServiceHealthResponse",
    "ServingDescribeServiceResponse",
    "ServingEmbedConfig",
    "ServingEndpointDescriptor",
    "ServingEndpointEventDetails",
    "ServingEnvironmentVariable",
    "ServingFeaturesStatus",
    "ServingGCPCredentials",
    "ServingGCSInferenceLoggingConfig",
    "ServingGetAPILogsRequest",
    "ServingGetAPILogsResponse",
    "ServingGetAllowedEnvironmentVariablesRequest",
    "ServingGetAllowedEnvironmentVariablesResponse",
    "ServingGetAllowedVLLMArgsResponse",
    "ServingGetApplicationLogsRequest",
    "ServingGetApplicationLogsResponse",
    "ServingGetEndpointEventRequest",
    "ServingGetEndpointEventResponse",
    "ServingGetEndpointLogsRequest",
    "ServingGetEndpointLogsResponse",
    "ServingGetEndpointRateLimitRequest",
    "ServingGetEndpointRateLimitResponse",
    "ServingGetQuotaUsageRequest",
    "ServingGetQuotaUsageResponse",
    "ServingGithubSourceCredentials",
    "ServingInferenceLoggingConfig",
    "ServingInstanceDetails",
    "ServingLabel",
    "ServingListApplicationsRequest",
    "ServingListApplicationsResponse",
    "ServingListClusterResourcesRequest",
    "ServingListClusterResourcesResponse",
    "ServingListEndpointsRequest",
    "ServingListEndpointsResponse",
    "ServingModelRevision",
    "ServingModelSource",
    "ServingModelStatus",
    "ServingOptimizationProfile",
    "ServingPodLogDetails",
    "ServingQuotaUsage",
    "ServingRankConfig",
    "ServingRateLimit",
    "ServingRateLimitConfig",
    "ServingRegistrySource",
    "ServingRelevantRevisionsMeta",
    "ServingRequestRateLimit",
    "ServingRequestResourceInfo",
    "ServingResources",
    "ServingRevisionMeta",
    "ServingRuntimeInfo",
    "ServingS3InferenceLoggingConfig",
    "ServingS3SourceCredentials",
    "ServingServiceStatus",
    "ServingSetEndpointRateLimitRequest",
    "ServingStartEndpointRequest",
    "ServingStopEndpointRequest",
    "ServingTextGenerationConfig",
    "ServingThirdPartySource",
    "ServingToggleFeaturesRequest",
    "ServingTokenBudget",
    "ServingTraffic",
    "ServingUpdateEndpointRequest",
    "ServingUpdateEndpointResponse",
    "ServingUpdateInferenceLoggingConfigRequest",
    "ServingVLLMEngineArgs",
]

# import apis into sdk package
from cloudera.ai.inference.api.serving_api import ServingApi as ServingApi

# import ApiClient
from cloudera.ai.inference.api_response import ApiResponse as ApiResponse
from cloudera.ai.inference.api_client import ApiClient as ApiClient
from cloudera.ai.inference.configuration import Configuration as Configuration
from cloudera.ai.inference.exceptions import OpenApiException as OpenApiException
from cloudera.ai.inference.exceptions import ApiTypeError as ApiTypeError
from cloudera.ai.inference.exceptions import ApiValueError as ApiValueError
from cloudera.ai.inference.exceptions import ApiKeyError as ApiKeyError
from cloudera.ai.inference.exceptions import ApiAttributeError as ApiAttributeError
from cloudera.ai.inference.exceptions import ApiException as ApiException

# import models into sdk package
from cloudera.ai.inference.models.archiver_cluster_log_archive_metadata import ArchiverClusterLogArchiveMetadata as ArchiverClusterLogArchiveMetadata
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_request import ArchiverCreateClusterLogArchiveRequest as ArchiverCreateClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_response import ArchiverCreateClusterLogArchiveResponse as ArchiverCreateClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_request import ArchiverDeleteClusterLogArchiveRequest as ArchiverDeleteClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_response import ArchiverDeleteClusterLogArchiveResponse as ArchiverDeleteClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_request import ArchiverListClusterLogArchivesRequest as ArchiverListClusterLogArchivesRequest
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_response import ArchiverListClusterLogArchivesResponse as ArchiverListClusterLogArchivesResponse
from cloudera.ai.inference.models.authorizer_grant_permission_request import AuthorizerGrantPermissionRequest as AuthorizerGrantPermissionRequest
from cloudera.ai.inference.models.authorizer_list_permissions_request import AuthorizerListPermissionsRequest as AuthorizerListPermissionsRequest
from cloudera.ai.inference.models.authorizer_list_permissions_response import AuthorizerListPermissionsResponse as AuthorizerListPermissionsResponse
from cloudera.ai.inference.models.authorizer_permission import AuthorizerPermission as AuthorizerPermission
from cloudera.ai.inference.models.authorizer_permissions import AuthorizerPermissions as AuthorizerPermissions
from cloudera.ai.inference.models.authorizer_resource import AuthorizerResource as AuthorizerResource
from cloudera.ai.inference.models.authorizer_revoke_permission_request import AuthorizerRevokePermissionRequest as AuthorizerRevokePermissionRequest
from cloudera.ai.inference.models.authorizer_subject import AuthorizerSubject as AuthorizerSubject
from cloudera.ai.inference.models.google_protobuf_any import GoogleProtobufAny as GoogleProtobufAny
from cloudera.ai.inference.models.google_rpc_status import GoogleRpcStatus as GoogleRpcStatus
from cloudera.ai.inference.models.serving_abs_inference_logging_config import ServingABSInferenceLoggingConfig as ServingABSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_aws_credentials import ServingAWSCredentials as ServingAWSCredentials
from cloudera.ai.inference.models.serving_application_container_source import ServingApplicationContainerSource as ServingApplicationContainerSource
from cloudera.ai.inference.models.serving_application_descriptor import ServingApplicationDescriptor as ServingApplicationDescriptor
from cloudera.ai.inference.models.serving_application_directory_source import ServingApplicationDirectorySource as ServingApplicationDirectorySource
from cloudera.ai.inference.models.serving_application_directory_source_credentials import ServingApplicationDirectorySourceCredentials as ServingApplicationDirectorySourceCredentials
from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision as ServingApplicationRevision
from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource as ServingApplicationSource
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling as ServingAutoscaling
from cloudera.ai.inference.models.serving_autoscaling_config import ServingAutoscalingConfig as ServingAutoscalingConfig
from cloudera.ai.inference.models.serving_condition import ServingCondition as ServingCondition
from cloudera.ai.inference.models.serving_data_lake_logging_config import ServingDataLakeLoggingConfig as ServingDataLakeLoggingConfig
from cloudera.ai.inference.models.serving_delete_application_request import ServingDeleteApplicationRequest as ServingDeleteApplicationRequest
from cloudera.ai.inference.models.serving_delete_endpoint_rate_limit_request import ServingDeleteEndpointRateLimitRequest as ServingDeleteEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_delete_endpoint_request import ServingDeleteEndpointRequest as ServingDeleteEndpointRequest
from cloudera.ai.inference.models.serving_deploy_application_request import ServingDeployApplicationRequest as ServingDeployApplicationRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_request import ServingDeployEndpointRequest as ServingDeployEndpointRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_response import ServingDeployEndpointResponse as ServingDeployEndpointResponse
from cloudera.ai.inference.models.serving_describe_application_request import ServingDescribeApplicationRequest as ServingDescribeApplicationRequest
from cloudera.ai.inference.models.serving_describe_application_response import ServingDescribeApplicationResponse as ServingDescribeApplicationResponse
from cloudera.ai.inference.models.serving_describe_endpoint_request import ServingDescribeEndpointRequest as ServingDescribeEndpointRequest
from cloudera.ai.inference.models.serving_describe_endpoint_response import ServingDescribeEndpointResponse as ServingDescribeEndpointResponse
from cloudera.ai.inference.models.serving_describe_service_health_response import ServingDescribeServiceHealthResponse as ServingDescribeServiceHealthResponse
from cloudera.ai.inference.models.serving_describe_service_response import ServingDescribeServiceResponse as ServingDescribeServiceResponse
from cloudera.ai.inference.models.serving_embed_config import ServingEmbedConfig as ServingEmbedConfig
from cloudera.ai.inference.models.serving_endpoint_descriptor import ServingEndpointDescriptor as ServingEndpointDescriptor
from cloudera.ai.inference.models.serving_endpoint_event_details import ServingEndpointEventDetails as ServingEndpointEventDetails
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable as ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_features_status import ServingFeaturesStatus as ServingFeaturesStatus
from cloudera.ai.inference.models.serving_gcp_credentials import ServingGCPCredentials as ServingGCPCredentials
from cloudera.ai.inference.models.serving_gcs_inference_logging_config import ServingGCSInferenceLoggingConfig as ServingGCSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_get_api_logs_request import ServingGetAPILogsRequest as ServingGetAPILogsRequest
from cloudera.ai.inference.models.serving_get_api_logs_response import ServingGetAPILogsResponse as ServingGetAPILogsResponse
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_request import ServingGetAllowedEnvironmentVariablesRequest as ServingGetAllowedEnvironmentVariablesRequest
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_response import ServingGetAllowedEnvironmentVariablesResponse as ServingGetAllowedEnvironmentVariablesResponse
from cloudera.ai.inference.models.serving_get_allowed_vllm_args_response import ServingGetAllowedVLLMArgsResponse as ServingGetAllowedVLLMArgsResponse
from cloudera.ai.inference.models.serving_get_application_logs_request import ServingGetApplicationLogsRequest as ServingGetApplicationLogsRequest
from cloudera.ai.inference.models.serving_get_application_logs_response import ServingGetApplicationLogsResponse as ServingGetApplicationLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_event_request import ServingGetEndpointEventRequest as ServingGetEndpointEventRequest
from cloudera.ai.inference.models.serving_get_endpoint_event_response import ServingGetEndpointEventResponse as ServingGetEndpointEventResponse
from cloudera.ai.inference.models.serving_get_endpoint_logs_request import ServingGetEndpointLogsRequest as ServingGetEndpointLogsRequest
from cloudera.ai.inference.models.serving_get_endpoint_logs_response import ServingGetEndpointLogsResponse as ServingGetEndpointLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_request import ServingGetEndpointRateLimitRequest as ServingGetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_response import ServingGetEndpointRateLimitResponse as ServingGetEndpointRateLimitResponse
from cloudera.ai.inference.models.serving_get_quota_usage_request import ServingGetQuotaUsageRequest as ServingGetQuotaUsageRequest
from cloudera.ai.inference.models.serving_get_quota_usage_response import ServingGetQuotaUsageResponse as ServingGetQuotaUsageResponse
from cloudera.ai.inference.models.serving_github_source_credentials import ServingGithubSourceCredentials as ServingGithubSourceCredentials
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig as ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_instance_details import ServingInstanceDetails as ServingInstanceDetails
from cloudera.ai.inference.models.serving_label import ServingLabel as ServingLabel
from cloudera.ai.inference.models.serving_list_applications_request import ServingListApplicationsRequest as ServingListApplicationsRequest
from cloudera.ai.inference.models.serving_list_applications_response import ServingListApplicationsResponse as ServingListApplicationsResponse
from cloudera.ai.inference.models.serving_list_cluster_resources_request import ServingListClusterResourcesRequest as ServingListClusterResourcesRequest
from cloudera.ai.inference.models.serving_list_cluster_resources_response import ServingListClusterResourcesResponse as ServingListClusterResourcesResponse
from cloudera.ai.inference.models.serving_list_endpoints_request import ServingListEndpointsRequest as ServingListEndpointsRequest
from cloudera.ai.inference.models.serving_list_endpoints_response import ServingListEndpointsResponse as ServingListEndpointsResponse
from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision as ServingModelRevision
from cloudera.ai.inference.models.serving_model_source import ServingModelSource as ServingModelSource
from cloudera.ai.inference.models.serving_model_status import ServingModelStatus as ServingModelStatus
from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile as ServingOptimizationProfile
from cloudera.ai.inference.models.serving_pod_log_details import ServingPodLogDetails as ServingPodLogDetails
from cloudera.ai.inference.models.serving_quota_usage import ServingQuotaUsage as ServingQuotaUsage
from cloudera.ai.inference.models.serving_rank_config import ServingRankConfig as ServingRankConfig
from cloudera.ai.inference.models.serving_rate_limit import ServingRateLimit as ServingRateLimit
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig as ServingRateLimitConfig
from cloudera.ai.inference.models.serving_registry_source import ServingRegistrySource as ServingRegistrySource
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta as ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_request_rate_limit import ServingRequestRateLimit as ServingRequestRateLimit
from cloudera.ai.inference.models.serving_request_resource_info import ServingRequestResourceInfo as ServingRequestResourceInfo
from cloudera.ai.inference.models.serving_resources import ServingResources as ServingResources
from cloudera.ai.inference.models.serving_revision_meta import ServingRevisionMeta as ServingRevisionMeta
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo as ServingRuntimeInfo
from cloudera.ai.inference.models.serving_s3_inference_logging_config import ServingS3InferenceLoggingConfig as ServingS3InferenceLoggingConfig
from cloudera.ai.inference.models.serving_s3_source_credentials import ServingS3SourceCredentials as ServingS3SourceCredentials
from cloudera.ai.inference.models.serving_service_status import ServingServiceStatus as ServingServiceStatus
from cloudera.ai.inference.models.serving_set_endpoint_rate_limit_request import ServingSetEndpointRateLimitRequest as ServingSetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_start_endpoint_request import ServingStartEndpointRequest as ServingStartEndpointRequest
from cloudera.ai.inference.models.serving_stop_endpoint_request import ServingStopEndpointRequest as ServingStopEndpointRequest
from cloudera.ai.inference.models.serving_text_generation_config import ServingTextGenerationConfig as ServingTextGenerationConfig
from cloudera.ai.inference.models.serving_third_party_source import ServingThirdPartySource as ServingThirdPartySource
from cloudera.ai.inference.models.serving_toggle_features_request import ServingToggleFeaturesRequest as ServingToggleFeaturesRequest
from cloudera.ai.inference.models.serving_token_budget import ServingTokenBudget as ServingTokenBudget
from cloudera.ai.inference.models.serving_traffic import ServingTraffic as ServingTraffic
from cloudera.ai.inference.models.serving_update_endpoint_request import ServingUpdateEndpointRequest as ServingUpdateEndpointRequest
from cloudera.ai.inference.models.serving_update_endpoint_response import ServingUpdateEndpointResponse as ServingUpdateEndpointResponse
from cloudera.ai.inference.models.serving_update_inference_logging_config_request import ServingUpdateInferenceLoggingConfigRequest as ServingUpdateInferenceLoggingConfigRequest
from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs as ServingVLLMEngineArgs


from cloudera.ai.inference._client import create_client
