# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_endpoint_event_details import ServingEndpointEventDetails

class TestServingEndpointEventDetails(unittest.TestCase):
    """ServingEndpointEventDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingEndpointEventDetails:
        """Test ServingEndpointEventDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingEndpointEventDetails`
        """
        model = ServingEndpointEventDetails()
        if include_optional:
            return ServingEndpointEventDetails(
                event_type = '',
                reason = '',
                event_trigger = '',
                message = '',
                last_seen = '',
                count = 56
            )
        else:
            return ServingEndpointEventDetails(
        )
        """

    def testServingEndpointEventDetails(self):
        """Test ServingEndpointEventDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
