# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_features_status import ServingFeaturesStatus
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeServiceResponse(BaseModel):
    """
    ServingDescribeServiceResponse
    """ # noqa: E501
    crn: Optional[StrictStr] = None
    version: Optional[StrictStr] = None
    features: Optional[ServingFeaturesStatus] = None
    api_versions: Optional[List[StrictStr]] = Field(default=None, alias="apiVersions")
    runtimes: Optional[List[ServingRuntimeInfo]] = None
    inference_logging_config: Optional[ServingInferenceLoggingConfig] = Field(default=None, alias="inferenceLoggingConfig")
    __properties: ClassVar[List[str]] = ["crn", "version", "features", "apiVersions", "runtimes", "inferenceLoggingConfig"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeServiceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of features
        if self.features:
            _dict['features'] = self.features.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in runtimes (list)
        _items = []
        if self.runtimes:
            for _item_runtimes in self.runtimes:
                if _item_runtimes:
                    _items.append(_item_runtimes.to_dict())
            _dict['runtimes'] = _items
        # override the default output from pydantic by calling `to_dict()` of inference_logging_config
        if self.inference_logging_config:
            _dict['inferenceLoggingConfig'] = self.inference_logging_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeServiceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "crn": obj.get("crn"),
            "version": obj.get("version"),
            "features": ServingFeaturesStatus.from_dict(obj["features"]) if obj.get("features") is not None else None,
            "apiVersions": obj.get("apiVersions"),
            "runtimes": [ServingRuntimeInfo.from_dict(_item) for _item in obj["runtimes"]] if obj.get("runtimes") is not None else None,
            "inferenceLoggingConfig": ServingInferenceLoggingConfig.from_dict(obj["inferenceLoggingConfig"]) if obj.get("inferenceLoggingConfig") is not None else None
        })
        return _obj


