# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision

class TestServingModelRevision(unittest.TestCase):
    """ServingModelRevision unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingModelRevision:
        """Test ServingModelRevision
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingModelRevision`
        """
        model = ServingModelRevision()
        if include_optional:
            return ServingModelRevision(
                source = cloudera.ai.inference.models.serving/model_source.serving.ModelSource(
                    registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                        model_id = '', 
                        version = 56, 
                        registry_id = '', ), 
                    third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                        url = '', 
                        model = '', 
                        provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                        api_key = '', 
                        aws_credentials = null, 
                        gcp_credentials = null, 
                        api_version = '', 
                        path_prefix = '', ), ),
                metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                    name = '', 
                    traffic = 56, 
                    desired_replicas = 56, 
                    actual_replicas = 56, 
                    ready = True, 
                    failed = True, 
                    generation = '', 
                    conditions = [
                        cloudera.ai.inference.models.serving/condition.serving.Condition(
                            type = '', 
                            status = '', 
                            severity = '', 
                            last_transition_time = '', 
                            reason = '', 
                            message = '', )
                        ], 
                    replica_names = [
                        ''
                        ], )
            )
        else:
            return ServingModelRevision(
        )
        """

    def testServingModelRevision(self):
        """Test ServingModelRevision"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
