# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_application_directory_source_credentials import ServingApplicationDirectorySourceCredentials

class TestServingApplicationDirectorySourceCredentials(unittest.TestCase):
    """ServingApplicationDirectorySourceCredentials unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingApplicationDirectorySourceCredentials:
        """Test ServingApplicationDirectorySourceCredentials
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingApplicationDirectorySourceCredentials`
        """
        model = ServingApplicationDirectorySourceCredentials()
        if include_optional:
            return ServingApplicationDirectorySourceCredentials(
                github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                    username = '', 
                    ssh_key = '', 
                    access_token = '', ),
                s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                    access_key_id = '', 
                    secret_access_key = '', )
            )
        else:
            return ServingApplicationDirectorySourceCredentials(
        )
        """

    def testServingApplicationDirectorySourceCredentials(self):
        """Test ServingApplicationDirectorySourceCredentials"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
