# coding: utf-8

# flake8: noqa
"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from cloudera.ai.inference.models.archiver_cluster_log_archive_metadata import ArchiverClusterLogArchiveMetadata
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_request import ArchiverCreateClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_response import ArchiverCreateClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_request import ArchiverDeleteClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_response import ArchiverDeleteClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_request import ArchiverListClusterLogArchivesRequest
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_response import ArchiverListClusterLogArchivesResponse
from cloudera.ai.inference.models.authorizer_grant_permission_request import AuthorizerGrantPermissionRequest
from cloudera.ai.inference.models.authorizer_list_permissions_request import AuthorizerListPermissionsRequest
from cloudera.ai.inference.models.authorizer_list_permissions_response import AuthorizerListPermissionsResponse
from cloudera.ai.inference.models.authorizer_permission import AuthorizerPermission
from cloudera.ai.inference.models.authorizer_permissions import AuthorizerPermissions
from cloudera.ai.inference.models.authorizer_resource import AuthorizerResource
from cloudera.ai.inference.models.authorizer_revoke_permission_request import AuthorizerRevokePermissionRequest
from cloudera.ai.inference.models.authorizer_subject import AuthorizerSubject
from cloudera.ai.inference.models.google_protobuf_any import GoogleProtobufAny
from cloudera.ai.inference.models.google_rpc_status import GoogleRpcStatus
from cloudera.ai.inference.models.serving_abs_inference_logging_config import ServingABSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_aws_credentials import ServingAWSCredentials
from cloudera.ai.inference.models.serving_application_container_source import ServingApplicationContainerSource
from cloudera.ai.inference.models.serving_application_descriptor import ServingApplicationDescriptor
from cloudera.ai.inference.models.serving_application_directory_source import ServingApplicationDirectorySource
from cloudera.ai.inference.models.serving_application_directory_source_credentials import ServingApplicationDirectorySourceCredentials
from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision
from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_autoscaling_config import ServingAutoscalingConfig
from cloudera.ai.inference.models.serving_condition import ServingCondition
from cloudera.ai.inference.models.serving_data_lake_logging_config import ServingDataLakeLoggingConfig
from cloudera.ai.inference.models.serving_delete_application_request import ServingDeleteApplicationRequest
from cloudera.ai.inference.models.serving_delete_endpoint_rate_limit_request import ServingDeleteEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_delete_endpoint_request import ServingDeleteEndpointRequest
from cloudera.ai.inference.models.serving_deploy_application_request import ServingDeployApplicationRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_request import ServingDeployEndpointRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_response import ServingDeployEndpointResponse
from cloudera.ai.inference.models.serving_describe_application_request import ServingDescribeApplicationRequest
from cloudera.ai.inference.models.serving_describe_application_response import ServingDescribeApplicationResponse
from cloudera.ai.inference.models.serving_describe_endpoint_request import ServingDescribeEndpointRequest
from cloudera.ai.inference.models.serving_describe_endpoint_response import ServingDescribeEndpointResponse
from cloudera.ai.inference.models.serving_describe_service_health_response import ServingDescribeServiceHealthResponse
from cloudera.ai.inference.models.serving_describe_service_response import ServingDescribeServiceResponse
from cloudera.ai.inference.models.serving_embed_config import ServingEmbedConfig
from cloudera.ai.inference.models.serving_endpoint_descriptor import ServingEndpointDescriptor
from cloudera.ai.inference.models.serving_endpoint_event_details import ServingEndpointEventDetails
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_features_status import ServingFeaturesStatus
from cloudera.ai.inference.models.serving_gcp_credentials import ServingGCPCredentials
from cloudera.ai.inference.models.serving_gcs_inference_logging_config import ServingGCSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_get_api_logs_request import ServingGetAPILogsRequest
from cloudera.ai.inference.models.serving_get_api_logs_response import ServingGetAPILogsResponse
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_request import ServingGetAllowedEnvironmentVariablesRequest
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_response import ServingGetAllowedEnvironmentVariablesResponse
from cloudera.ai.inference.models.serving_get_allowed_vllm_args_response import ServingGetAllowedVLLMArgsResponse
from cloudera.ai.inference.models.serving_get_application_logs_request import ServingGetApplicationLogsRequest
from cloudera.ai.inference.models.serving_get_application_logs_response import ServingGetApplicationLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_event_request import ServingGetEndpointEventRequest
from cloudera.ai.inference.models.serving_get_endpoint_event_response import ServingGetEndpointEventResponse
from cloudera.ai.inference.models.serving_get_endpoint_logs_request import ServingGetEndpointLogsRequest
from cloudera.ai.inference.models.serving_get_endpoint_logs_response import ServingGetEndpointLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_request import ServingGetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_response import ServingGetEndpointRateLimitResponse
from cloudera.ai.inference.models.serving_get_quota_usage_request import ServingGetQuotaUsageRequest
from cloudera.ai.inference.models.serving_get_quota_usage_response import ServingGetQuotaUsageResponse
from cloudera.ai.inference.models.serving_github_source_credentials import ServingGithubSourceCredentials
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_instance_details import ServingInstanceDetails
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_list_applications_request import ServingListApplicationsRequest
from cloudera.ai.inference.models.serving_list_applications_response import ServingListApplicationsResponse
from cloudera.ai.inference.models.serving_list_cluster_resources_request import ServingListClusterResourcesRequest
from cloudera.ai.inference.models.serving_list_cluster_resources_response import ServingListClusterResourcesResponse
from cloudera.ai.inference.models.serving_list_endpoints_request import ServingListEndpointsRequest
from cloudera.ai.inference.models.serving_list_endpoints_response import ServingListEndpointsResponse
from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision
from cloudera.ai.inference.models.serving_model_source import ServingModelSource
from cloudera.ai.inference.models.serving_model_status import ServingModelStatus
from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile
from cloudera.ai.inference.models.serving_pod_log_details import ServingPodLogDetails
from cloudera.ai.inference.models.serving_quota_usage import ServingQuotaUsage
from cloudera.ai.inference.models.serving_rank_config import ServingRankConfig
from cloudera.ai.inference.models.serving_rate_limit import ServingRateLimit
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig
from cloudera.ai.inference.models.serving_registry_source import ServingRegistrySource
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_request_rate_limit import ServingRequestRateLimit
from cloudera.ai.inference.models.serving_request_resource_info import ServingRequestResourceInfo
from cloudera.ai.inference.models.serving_resources import ServingResources
from cloudera.ai.inference.models.serving_revision_meta import ServingRevisionMeta
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo
from cloudera.ai.inference.models.serving_s3_inference_logging_config import ServingS3InferenceLoggingConfig
from cloudera.ai.inference.models.serving_s3_source_credentials import ServingS3SourceCredentials
from cloudera.ai.inference.models.serving_service_status import ServingServiceStatus
from cloudera.ai.inference.models.serving_set_endpoint_rate_limit_request import ServingSetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_start_endpoint_request import ServingStartEndpointRequest
from cloudera.ai.inference.models.serving_stop_endpoint_request import ServingStopEndpointRequest
from cloudera.ai.inference.models.serving_text_generation_config import ServingTextGenerationConfig
from cloudera.ai.inference.models.serving_third_party_source import ServingThirdPartySource
from cloudera.ai.inference.models.serving_toggle_features_request import ServingToggleFeaturesRequest
from cloudera.ai.inference.models.serving_token_budget import ServingTokenBudget
from cloudera.ai.inference.models.serving_traffic import ServingTraffic
from cloudera.ai.inference.models.serving_update_endpoint_request import ServingUpdateEndpointRequest
from cloudera.ai.inference.models.serving_update_endpoint_response import ServingUpdateEndpointResponse
from cloudera.ai.inference.models.serving_update_inference_logging_config_request import ServingUpdateInferenceLoggingConfigRequest
from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs

