# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_application_response import ServingDescribeApplicationResponse

class TestServingDescribeApplicationResponse(unittest.TestCase):
    """ServingDescribeApplicationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeApplicationResponse:
        """Test ServingDescribeApplicationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeApplicationResponse`
        """
        model = ServingDescribeApplicationResponse()
        if include_optional:
            return ServingDescribeApplicationResponse(
                namespace = '',
                name = '',
                url = '',
                conditions = [
                    cloudera.ai.inference.models.serving/condition.serving.Condition(
                        type = '', 
                        status = '', 
                        severity = '', 
                        last_transition_time = '', 
                        reason = '', 
                        message = '', )
                    ],
                subdomain = '',
                observed_generation = 56,
                created_by = '',
                description = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                revisions = [
                    cloudera.ai.inference.models.serving/application_revision.serving.ApplicationRevision(
                        source = cloudera.ai.inference.models.serving/application_source.serving.ApplicationSource(
                            container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                                url = '', 
                                environment_variables = [
                                    cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                                        name = '', 
                                        value = '', )
                                    ], 
                                username = '', 
                                access_token = '', ), 
                            directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                                url = '', 
                                entry_point = '', 
                                runtime_image = '', 
                                credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                                    github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                                        username = '', 
                                        ssh_key = '', 
                                        access_token = '', ), 
                                    s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                                        access_key_id = '', 
                                        secret_access_key = '', ), ), ), ), 
                        metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                            name = '', 
                            traffic = 56, 
                            desired_replicas = 56, 
                            actual_replicas = 56, 
                            ready = True, 
                            failed = True, 
                            generation = '', 
                            conditions = [
                                cloudera.ai.inference.models.serving/condition.serving.Condition(
                                    type = '', 
                                    status = '', 
                                    severity = '', 
                                    last_transition_time = '', 
                                    reason = '', 
                                    message = '', )
                                ], 
                            replica_names = [
                                ''
                                ], ), )
                    ],
                relevant_revisions = cloudera.ai.inference.models.serving/relevant_revisions_meta.serving.RelevantRevisionsMeta(
                    latest_created_revision = '', 
                    latest_ready_revision = '', 
                    latest_rolledout_revision = '', 
                    previous_rolledout_revision = '', ),
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                state = '',
                last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_web_app = True,
                source_url = ''
            )
        else:
            return ServingDescribeApplicationResponse(
        )
        """

    def testServingDescribeApplicationResponse(self):
        """Test ServingDescribeApplicationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
