# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ServingQuotaUsage(BaseModel):
    """
    Quota usage details for a single scope/metric combination
    """ # noqa: E501
    scope: Optional[StrictStr] = Field(default=None, description="\"user\" or \"group\"")
    identifier: Optional[StrictStr] = Field(default=None, description="username or group name")
    metric: Optional[StrictStr] = Field(default=None, description="\"requests\" or \"tokens\"")
    used: Optional[StrictStr] = Field(default=None, description="amount consumed in current window")
    limit: Optional[StrictStr] = Field(default=None, description="configured limit")
    remaining: Optional[StrictStr] = Field(default=None, description="limit - used")
    unit: Optional[StrictStr] = Field(default=None, description="time window unit")
    resets_at: Optional[StrictStr] = Field(default=None, description="unix timestamp when window resets")
    __properties: ClassVar[List[str]] = ["scope", "identifier", "metric", "used", "limit", "remaining", "unit", "resets_at"]

    @field_validator('unit')
    def unit_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['RATE_LIMIT_UNIT_UNKNOWN', 'SECOND', 'MINUTE', 'HOUR', 'DAY']):
            raise ValueError("must be one of enum values ('RATE_LIMIT_UNIT_UNKNOWN', 'SECOND', 'MINUTE', 'HOUR', 'DAY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingQuotaUsage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingQuotaUsage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "scope": obj.get("scope"),
            "identifier": obj.get("identifier"),
            "metric": obj.get("metric"),
            "used": obj.get("used"),
            "limit": obj.get("limit"),
            "remaining": obj.get("remaining"),
            "unit": obj.get("unit"),
            "resets_at": obj.get("resets_at")
        })
        return _obj


