# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision

class TestServingApplicationRevision(unittest.TestCase):
    """ServingApplicationRevision unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingApplicationRevision:
        """Test ServingApplicationRevision
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingApplicationRevision`
        """
        model = ServingApplicationRevision()
        if include_optional:
            return ServingApplicationRevision(
                source = cloudera.ai.inference.models.serving/application_source.serving.ApplicationSource(
                    container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                        url = '', 
                        environment_variables = [
                            cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                                name = '', 
                                value = '', )
                            ], 
                        username = '', 
                        access_token = '', ), 
                    directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                        url = '', 
                        entry_point = '', 
                        runtime_image = '', 
                        credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                            github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                                username = '', 
                                ssh_key = '', 
                                access_token = '', ), 
                            s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                                access_key_id = '', 
                                secret_access_key = '', ), ), ), ),
                metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                    name = '', 
                    traffic = 56, 
                    desired_replicas = 56, 
                    actual_replicas = 56, 
                    ready = True, 
                    failed = True, 
                    generation = '', 
                    conditions = [
                        cloudera.ai.inference.models.serving/condition.serving.Condition(
                            type = '', 
                            status = '', 
                            severity = '', 
                            last_transition_time = '', 
                            reason = '', 
                            message = '', )
                        ], 
                    replica_names = [
                        ''
                        ], )
            )
        else:
            return ServingApplicationRevision(
        )
        """

    def testServingApplicationRevision(self):
        """Test ServingApplicationRevision"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
