# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_endpoint_response import ServingDescribeEndpointResponse

class TestServingDescribeEndpointResponse(unittest.TestCase):
    """ServingDescribeEndpointResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeEndpointResponse:
        """Test ServingDescribeEndpointResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeEndpointResponse`
        """
        model = ServingDescribeEndpointResponse()
        if include_optional:
            return ServingDescribeEndpointResponse(
                namespace = '',
                name = '',
                url = '',
                conditions = [
                    cloudera.ai.inference.models.serving/condition.serving.Condition(
                        type = '', 
                        status = '', 
                        severity = '', 
                        last_transition_time = '', 
                        reason = '', 
                        message = '', )
                    ],
                status = cloudera.ai.inference.models.serving/model_status.serving.ModelStatus(
                    failed_copies = 56, 
                    total_copies = 56, 
                    active_model_state = '', 
                    target_model_state = '', 
                    transition_status = '', ),
                observed_generation = 56,
                replica_count = 56,
                created_by = '',
                description = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                revisions = [
                    cloudera.ai.inference.models.serving/model_revision.serving.ModelRevision(
                        source = cloudera.ai.inference.models.serving/model_source.serving.ModelSource(
                            registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                                model_id = '', 
                                version = 56, 
                                registry_id = '', ), 
                            third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                                url = '', 
                                model = '', 
                                provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                                api_key = '', 
                                aws_credentials = null, 
                                gcp_credentials = null, 
                                api_version = '', 
                                path_prefix = '', ), ), 
                        metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                            name = '', 
                            traffic = 56, 
                            desired_replicas = 56, 
                            actual_replicas = 56, 
                            ready = True, 
                            failed = True, 
                            generation = '', 
                            conditions = [
                                cloudera.ai.inference.models.serving/condition.serving.Condition(
                                    type = '', 
                                    status = '', 
                                    severity = '', 
                                    last_transition_time = '', 
                                    reason = '', 
                                    message = '', )
                                ], 
                            replica_names = [
                                ''
                                ], ), )
                    ],
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                relevant_revisions = cloudera.ai.inference.models.serving/relevant_revisions_meta.serving.RelevantRevisionsMeta(
                    latest_created_revision = '', 
                    latest_ready_revision = '', 
                    latest_rolledout_revision = '', 
                    previous_rolledout_revision = '', ),
                model_name = '',
                traffic = cloudera.ai.inference.models.serving/traffic.serving.Traffic(
                    current_revision_traffic = '', 
                    previous_revision_traffic = '', ),
                api_standard = '',
                has_chat_template = True,
                metric_format = '',
                task = '',
                instance_type = '',
                optimization_profile = cloudera.ai.inference.models.serving/optimization_profile.serving.OptimizationProfile(
                    gpu = '', 
                    gpu_device = '', 
                    gpu_count = '', 
                    precision = '', 
                    release = '', 
                    embed_config = cloudera.ai.inference.models.serving/embed_config.serving.EmbedConfig(
                        dimension = 56, 
                        max_tokens = 56, ), 
                    text_gen_config = cloudera.ai.inference.models.serving/text_generation_config.serving.TextGenerationConfig(
                        llm_engine = '', 
                        max_image_size = '', 
                        profile = '', ), 
                    rank_config = cloudera.ai.inference.models.serving/rank_config.serving.RankConfig(
                        max_tokens = 56, 
                        max_passages = 56, ), ),
                crn = '',
                inference_logging_config = cloudera.ai.inference.models.serving/inference_logging_config.serving.InferenceLoggingConfig(
                    enabled = True, 
                    explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    transformer_s3_config = , 
                    transformer_abs_config = , 
                    transformer_gcs_config = , 
                    transformer_datalake_config = , 
                    format = 'LOGGING_FORMAT_UNKNOWN', 
                    batch_size = 56, 
                    rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN', ),
                runtime_info = cloudera.ai.inference.models.serving/runtime_info.serving.RuntimeInfo(
                    display_name = '', 
                    version = '', 
                    image_identifier = '', 
                    vllm_version = '', 
                    transformers_library_version = '', 
                    latest_version = True, 
                    runtime_name = '', ),
                vllm_args = '',
                deployment_mode = 'DEPLOYMENT_MODE_UNKNOWN',
                environment_variables = [
                    cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                        name = '', 
                        value = '', )
                    ],
                gpu_type = '',
                tags = [
                    cloudera.ai.inference.models.serving/label.serving.Label(
                        key = '', 
                        value = '', )
                    ],
                rate_limit = cloudera.ai.inference.models.serving/rate_limit_config.serving.RateLimitConfig(
                    request_rate = null, 
                    token_budget = null, ),
                state = ''
            )
        else:
            return ServingDescribeEndpointResponse(
        )
        """

    def testServingDescribeEndpointResponse(self):
        """Test ServingDescribeEndpointResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
