# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.archiver_create_cluster_log_archive_request import ArchiverCreateClusterLogArchiveRequest

class TestArchiverCreateClusterLogArchiveRequest(unittest.TestCase):
    """ArchiverCreateClusterLogArchiveRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArchiverCreateClusterLogArchiveRequest:
        """Test ArchiverCreateClusterLogArchiveRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArchiverCreateClusterLogArchiveRequest`
        """
        model = ArchiverCreateClusterLogArchiveRequest()
        if include_optional:
            return ArchiverCreateClusterLogArchiveRequest(
                uuid = '',
                timespan_minutes = 56,
                include_endpoints = True,
                redact_sensitive_data = True,
                send_to_cloudera = True,
                case_number = '',
                include_applications = True
            )
        else:
            return ArchiverCreateClusterLogArchiveRequest(
        )
        """

    def testArchiverCreateClusterLogArchiveRequest(self):
        """Test ArchiverCreateClusterLogArchiveRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
