# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_revision_meta import ServingRevisionMeta

class TestServingRevisionMeta(unittest.TestCase):
    """ServingRevisionMeta unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingRevisionMeta:
        """Test ServingRevisionMeta
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingRevisionMeta`
        """
        model = ServingRevisionMeta()
        if include_optional:
            return ServingRevisionMeta(
                name = '',
                traffic = 56,
                desired_replicas = 56,
                actual_replicas = 56,
                ready = True,
                failed = True,
                generation = '',
                conditions = [
                    cloudera.ai.inference.models.serving/condition.serving.Condition(
                        type = '', 
                        status = '', 
                        severity = '', 
                        last_transition_time = '', 
                        reason = '', 
                        message = '', )
                    ],
                replica_names = [
                    ''
                    ]
            )
        else:
            return ServingRevisionMeta(
        )
        """

    def testServingRevisionMeta(self):
        """Test ServingRevisionMeta"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
