# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs

class TestServingVLLMEngineArgs(unittest.TestCase):
    """ServingVLLMEngineArgs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingVLLMEngineArgs:
        """Test ServingVLLMEngineArgs
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingVLLMEngineArgs`
        """
        model = ServingVLLMEngineArgs()
        if include_optional:
            return ServingVLLMEngineArgs(
                dtype = '',
                enable_prefix_caching = True,
                gpu_memory_utilization = 1.337,
                load_format = '',
                max_model_length = 56,
                max_num_batched_tokens = 56,
                max_num_seqs = 56,
                quantization = '',
                enforce_eager = True,
                trust_remote_code = True,
                kv_cache_dtype = '',
                block_size = 56,
                cpu_offload_gb = 56
            )
        else:
            return ServingVLLMEngineArgs(
        )
        """

    def testServingVLLMEngineArgs(self):
        """Test ServingVLLMEngineArgs"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
