# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_model_source import ServingModelSource

class TestServingModelSource(unittest.TestCase):
    """ServingModelSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingModelSource:
        """Test ServingModelSource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingModelSource`
        """
        model = ServingModelSource()
        if include_optional:
            return ServingModelSource(
                registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                    model_id = '', 
                    version = 56, 
                    registry_id = '', ),
                third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                    url = '', 
                    model = '', 
                    provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                    api_key = '', 
                    aws_credentials = null, 
                    gcp_credentials = null, 
                    api_version = '', 
                    path_prefix = '', )
            )
        else:
            return ServingModelSource(
        )
        """

    def testServingModelSource(self):
        """Test ServingModelSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
