# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource

class TestServingApplicationSource(unittest.TestCase):
    """ServingApplicationSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingApplicationSource:
        """Test ServingApplicationSource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingApplicationSource`
        """
        model = ServingApplicationSource()
        if include_optional:
            return ServingApplicationSource(
                container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                    url = '', 
                    environment_variables = [
                        cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                            name = '', 
                            value = '', )
                        ], 
                    username = '', 
                    access_token = '', ),
                directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                    url = '', 
                    entry_point = '', 
                    runtime_image = '', 
                    environment_variables = [
                        cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                            name = '', 
                            value = '', )
                        ], 
                    credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                        github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                            username = '', 
                            ssh_key = '', 
                            access_token = '', ), 
                        s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                            access_key_id = '', 
                            secret_access_key = '', ), ), )
            )
        else:
            return ServingApplicationSource(
        )
        """

    def testServingApplicationSource(self):
        """Test ServingApplicationSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
