# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_get_quota_usage_response import ServingGetQuotaUsageResponse

class TestServingGetQuotaUsageResponse(unittest.TestCase):
    """ServingGetQuotaUsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingGetQuotaUsageResponse:
        """Test ServingGetQuotaUsageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingGetQuotaUsageResponse`
        """
        model = ServingGetQuotaUsageResponse()
        if include_optional:
            return ServingGetQuotaUsageResponse(
                usage = [
                    cloudera.ai.inference.models.serving/quota_usage.serving.QuotaUsage(
                        scope = '', 
                        identifier = '', 
                        metric = '', 
                        used = '', 
                        limit = '', 
                        remaining = '', 
                        unit = 'RATE_LIMIT_UNIT_UNKNOWN', 
                        resets_at = '', )
                    ]
            )
        else:
            return ServingGetQuotaUsageResponse(
        )
        """

    def testServingGetQuotaUsageResponse(self):
        """Test ServingGetQuotaUsageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
