# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_deploy_endpoint_request import ServingDeployEndpointRequest

class TestServingDeployEndpointRequest(unittest.TestCase):
    """ServingDeployEndpointRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDeployEndpointRequest:
        """Test ServingDeployEndpointRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDeployEndpointRequest`
        """
        model = ServingDeployEndpointRequest()
        if include_optional:
            return ServingDeployEndpointRequest(
                namespace = '',
                name = '',
                source = cloudera.ai.inference.models.serving/model_source.serving.ModelSource(
                    registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                        model_id = '', 
                        version = 56, 
                        registry_id = '', ), 
                    third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                        url = '', 
                        model = '', 
                        provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                        api_key = '', 
                        aws_credentials = null, 
                        gcp_credentials = null, 
                        api_version = '', 
                        path_prefix = '', ), ),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                labels = [
                    cloudera.ai.inference.models.serving/label.serving.Label(
                        key = '', 
                        value = '', )
                    ],
                description = '',
                traffic = '',
                vllm_engine_args = cloudera.ai.inference.models.serving/vllm_engine_args.serving.VLLMEngineArgs(
                    dtype = '', 
                    enable_prefix_caching = True, 
                    gpu_memory_utilization = 1.337, 
                    load_format = '', 
                    max_model_length = 56, 
                    max_num_batched_tokens = 56, 
                    max_num_seqs = 56, 
                    quantization = '', 
                    enforce_eager = True, 
                    trust_remote_code = True, 
                    kv_cache_dtype = '', 
                    block_size = 56, 
                    cpu_offload_gb = 56, ),
                instance_type = '',
                gpu_type = '',
                inference_logging_config = cloudera.ai.inference.models.serving/inference_logging_config.serving.InferenceLoggingConfig(
                    enabled = True, 
                    explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    transformer_s3_config = , 
                    transformer_abs_config = , 
                    transformer_gcs_config = , 
                    transformer_datalake_config = , 
                    format = 'LOGGING_FORMAT_UNKNOWN', 
                    batch_size = 56, 
                    rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN', ),
                ml_user_permission = '',
                vllm_args = '',
                deployment_mode = 'DEPLOYMENT_MODE_UNKNOWN',
                environment_variables = [
                    cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                        name = '', 
                        value = '', )
                    ],
                task_override = 'TASK_UNKNOWN',
                rate_limit = cloudera.ai.inference.models.serving/rate_limit_config.serving.RateLimitConfig(
                    request_rate = null, 
                    token_budget = null, )
            )
        else:
            return ServingDeployEndpointRequest(
        )
        """

    def testServingDeployEndpointRequest(self):
        """Test ServingDeployEndpointRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
