# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile

class TestServingOptimizationProfile(unittest.TestCase):
    """ServingOptimizationProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingOptimizationProfile:
        """Test ServingOptimizationProfile
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingOptimizationProfile`
        """
        model = ServingOptimizationProfile()
        if include_optional:
            return ServingOptimizationProfile(
                gpu = '',
                gpu_device = '',
                gpu_count = '',
                precision = '',
                release = '',
                embed_config = cloudera.ai.inference.models.serving/embed_config.serving.EmbedConfig(
                    dimension = 56, 
                    max_tokens = 56, ),
                text_gen_config = cloudera.ai.inference.models.serving/text_generation_config.serving.TextGenerationConfig(
                    llm_engine = '', 
                    max_image_size = '', 
                    profile = '', ),
                rank_config = cloudera.ai.inference.models.serving/rank_config.serving.RankConfig(
                    max_tokens = 56, 
                    max_passages = 56, )
            )
        else:
            return ServingOptimizationProfile(
        )
        """

    def testServingOptimizationProfile(self):
        """Test ServingOptimizationProfile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
