# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling

class TestServingAutoscaling(unittest.TestCase):
    """ServingAutoscaling unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingAutoscaling:
        """Test ServingAutoscaling
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingAutoscaling`
        """
        model = ServingAutoscaling()
        if include_optional:
            return ServingAutoscaling(
                min_replicas = '',
                max_replicas = '',
                autoscaling_config = cloudera.ai.inference.models.serving/autoscaling_config.serving.AutoscalingConfig(
                    metric = '', 
                    target = '', 
                    target_utilization = '', 
                    scale_to_zero_retention = '', 
                    activation_scale = '', 
                    scale_down_delay = '', 
                    panic_window_percentage = '', 
                    panic_threshold = '', 
                    stable_window = '', )
            )
        else:
            return ServingAutoscaling(
        )
        """

    def testServingAutoscaling(self):
        """Test ServingAutoscaling"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
