# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_resources import ServingResources
from typing import Optional, Set
from typing_extensions import Self

class ServingDeployApplicationRequest(BaseModel):
    """
    ServingDeployApplicationRequest
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    subdomain: Optional[StrictStr] = None
    source: Optional[ServingApplicationSource] = None
    resources: Optional[ServingResources] = None
    autoscaling: Optional[ServingAutoscaling] = None
    labels: Optional[List[ServingLabel]] = None
    description: Optional[StrictStr] = None
    traffic: Optional[StrictStr] = None
    instance_type: Optional[StrictStr] = None
    is_update: Optional[StrictBool] = None
    is_web_app: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["namespace", "name", "subdomain", "source", "resources", "autoscaling", "labels", "description", "traffic", "instance_type", "is_update", "is_web_app"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDeployApplicationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict['labels'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDeployApplicationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "subdomain": obj.get("subdomain"),
            "source": ServingApplicationSource.from_dict(obj["source"]) if obj.get("source") is not None else None,
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "labels": [ServingLabel.from_dict(_item) for _item in obj["labels"]] if obj.get("labels") is not None else None,
            "description": obj.get("description"),
            "traffic": obj.get("traffic"),
            "instance_type": obj.get("instance_type"),
            "is_update": obj.get("is_update"),
            "is_web_app": obj.get("is_web_app")
        })
        return _obj


